@@ -123,11 +123,13 @@ prettyc <- function(x) {
   dict <- matrix(ncol=2, byrow=TRUE, c(
     "Burkina Faso \\(Upper Volta\\)", "Burkina Faso",
     "Bolivia, Plurinational State of", "Bolivia",
+    "Cambodia \\(Kampuchea\\)", "Cambodia",
     "Central African Republic", "CAR",
     "Congo, the Democratic Republic of the", "DR Congo",
     "Congo, Democratic Republic of \\(Zaire\\)", "DR Congo",
     "Federal Republic of Germany", "Germany",
     "Federated States of Micronesia", "Micronesia",
+    "German Federal Republic", "Germany",
     "Korea, Democratic People's Republic of", "North Korea",
     "Korea, People's Republic of", "North Korea",
     "Korea, Republic of", "South Korea",
@@ -138,7 +140,9 @@ prettyc <- function(x) {
     "Myanmar \\(Burma\\)", "Myanmar",
     "Iran, Islamic Republic of", "Iran",
     "Iran \\(Persia\\)", "Iran",
+    "Italy/Sardinia", "Italy",
     "Russian Federation", "Russia",
+    "Russia \\(Soviet Union\\)", "Russia",
     "Sri Lanka \\(Ceylon\\)", "Sri Lanka",
     "Syrian Arab Republic", "Syria",
     "Tanzania, United Republic of", "Tanzania",
